# -*- coding: utf-8 -*-

from django.apps import AppConfig


class BaderConfig(AppConfig):
    name = "simmate.apps.bader"


class CleaseConfig(AppConfig):
    name = "simmate.apps.clease"


class VaspConfig(AppConfig):
    name = "simmate.apps.vasp"


class EvolutionConfig(AppConfig):
    name = "simmate.apps.evolution"
